===============
emails-gdpr
===============


.. image:: https://img.shields.io/pypi/v/emails-gdpr.svg
        :target: https://pypi.python.org/pypi/emails-gdpr



`emails-gdpr` is a small package used for discovering emails (and its domains) from thunderbird client,
that you have never replied to.




Installation
------------
* Use :code:`pip install emails-gdpr` to install

Usage
------

* Use :code:`emails-gdpr` to run the application

License
-------

* Free software: MIT license


TODO
----

* Create a way to simply change parameters via CLI
* Add discovery of Data Protection Officer contact details
* Add possibility to generate 'Right to be forgotten' letter
* Create tests
* Create GUI


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
